==> nocc-1.9.5.txz: usr/local/www/nocc/lang/zh-hans.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: zh-hans.php 2627 2014-11-14 12:52:31Z siebrand $
 */
/** Simplified Chinese (中文（简体）‎)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Cathypilot0117
 * @author Hydra
 * @author Liu Hong <loyaliu@21cn.com>
 * @author Liuxinyu970226
 * @author PhiLiP
 * @author Wilsonmess
 * @author Yfdyh000
 */

$lang_locale = 'zh_CN.UTF-8';
$default_date_format = '%Y年%m月%d日';
$no_locale_date_format = '%Y年-%m月-%d日';
$default_time_format = '%I:%M %p';
$err_user_empty = '用户名为空';
$err_passwd_empty = '密码为空';
$alt_delete = '删除选择的邮件';
$alt_delete_one = '删除邮件';
$alt_new_msg = '新消息';
$alt_reply = '回复作者';
$alt_reply_all = '回复所有';
$alt_forward = '转发';
$alt_next = '下一个';
$alt_prev = '上一个';
$title_next_page = '下一页';
$title_prev_page = '上一页';
$title_next_msg = '下一个邮件';
$title_prev_msg = '上一个邮件';
$html_theme_label = '主题：';
$html_welcome = '欢迎来到%1$s';
$html_login = '登录';
$html_user_label = '用户：';
$html_passwd_label = '密码：';
$html_submit = '提交';
$html_help = '帮助';
$html_server_label = '服务器：';
$html_wrong = '用户名或密码不正确';
$html_retry = '重试';
$html_remember = '记住设置';
$html_lang_label = '语言：';
$html_msgperpage_label = '每页消息数：';
$html_preferences = '参数设置';
$html_full_name_label = '全名：';
$html_email_address_label = '电邮地址：';
$html_bccself = '密件抄送自我';
$html_hide_addresses = '隐藏地址';
$html_outlook_quoting = '使用Microsoft Outlook样式的引用';
$html_reply_to = '回复';
$html_reply_to_label = '回复：';
$html_use_signature = '用户签名';
$html_signature = '签名';
$html_signature_label = '签名：';
$html_reply_leadin_label = '中铅对的回复：';
$html_prefs_updated = '参数设置已更新';
$html_manage_folders_link = '管理 IMAP 文件夹';
$html_manage_filters_link = '管理电子邮件过滤器';
$html_use_graphical_smilies = '使用图形化的表情符号';
$html_sent_folder_label = '将已发送邮件复制至专用的文件夹：';
$html_trash_folder_label = '将欲删除邮件移动至专用的文件夹：';
$html_colored_quotes = '彩色引用';
$html_display_struct = '结构化的显示文本';
$html_send_html_mail = '以HTML格式发送电子邮件';
$html_folders = '文件夹';
$html_folders_create_failed = '无法创建文件夹！';
$html_folders_sub_failed = '无法订阅至文件夹！';
$html_folders_unsub_failed = '无法从文件夹退订！';
$html_folders_rename_failed = '文件夹无法重命名！';
$html_folders_updated = '文件夹已更新';
$html_folder_subscribe = '订阅';
$html_folder_rename = '重命名';
$html_folder_create = '创建新文件夹';
$html_folder_remove = '取消订阅';
$html_folder_delete = '删除';
$html_folder_to = '至';
$html_filter_remove = '删除';
$html_filter_body = '邮件正文';
$html_filter_subject = '邮件主题';
$html_filter_to = '字段';
$html_filter_cc = '抄送字段';
$html_filter_from = '从字段';
$html_filter_change_tip = '若要更改筛选器只是覆盖它。';
$html_reapply_filters = '重新应用的所有筛选器';
$html_filter_contains = '包含';
$html_filter_name = '筛选器名称';
$html_filter_action = '筛选操作';
$html_filter_moveto = '移动到';
$html_select_one = '--选择其一--';
$html_and = '和';
$html_new_msg_in = '新消息于';
$html_or = '或';
$html_move = '移动';
$html_copy = '拷贝';
$html_messages_to = '选定的邮件';
$html_gotopage = '转到页';
$html_gotofolder = '转到文件夹';
$html_other_folders = '文件夹列表';
$html_page = '页面';
$html_of = '/';
$html_view_header = '浏览邮件头';
$html_remove_header = '隐藏邮件头';
$html_inbox = '收件箱';
$html_new_msg = '写邮件';
$html_reply = '回复';
$html_reply_short = '回复：';
$html_reply_all = '回复所有';
$html_forward = '转发';
$html_forward_short = '转发：';
$html_forward_info = '转发的邮件将这一以附件的形式发送。';
$html_delete = '删除';
$html_new = '新';
$html_mark = '删除';
$html_att_label = '附件：';
$html_atts_label = '附件:';
$html_unknown = '[未知]';
$html_part_x = '部分 %s';
$html_attach = '附件';
$html_attach_forget = '在发送邮件之前，你必须选一个文件!';
$html_attach_delete = '删除选择';
$html_attach_none = '您必须选择要附加的文件！';
$html_sort_by = '按排序';
$html_sort = '排序';
$html_from = '发件人';
$html_from_label = '从：';
$html_subject = '主题';
$html_subject_label = '主题：';
$html_date = '日期';
$html_date_label = '日期：';
$html_sent_label = '发送';
$html_wrote = '写道';
$html_quote_wrote = '在%1$s %2$s，%3$s写到：';
$html_size = '大小';
$html_totalsize = '总大小';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = '字节';
$html_filename = '文件名';
$html_to = '自';
$html_to_label = '自：';
$html_cc = '抄送';
$html_cc_label = '抄送：';
$html_bcc_label = '密送：';
$html_nosubject = '没有主题';
$html_send = '发送';
$html_cancel = '取消';
$html_no_mail = '没有邮件.';
$html_logout = '退出';
$html_msg = '邮件';
$html_msgs = '邮件';
$html_configuration = '此服务器未做好设置！';
$html_priority = '优先';
$html_priority_label = '优先级：';
$html_lowest = '最低';
$html_low = '低';
$html_normal = '正常';
$html_high = '高';
$html_highest = '最高';
$html_flagged = '标记';
$html_spam = '垃圾邮件';
$html_spam_warning = '此消息已被列为垃圾邮件。';
$html_receipt = '请求返回回执';
$html_select = '请选择';
$html_select_all = '反向选择';
$html_select_contacts = '选择联系人';
$html_loading_image = '加载图像';
$html_send_confirmed = '您的电子邮件被接受为传递';
$html_no_sendaction = '没有指定的操作。尝试启用 JavaScript。';
$html_error_occurred = '出现了一个错误';
$html_prefs_file_error = '无法打开首选项文件以进行写入。';
$html_wrap = '要自动换行，传出消息的字符数：';
$html_wrap_none = '不换行';
$html_usenet_separator = '新闻组分隔符（"-- \n"）在签名之前';
$html_mark_as = '将标记为';
$html_read = '阅读';
$html_unread = '未读';
$html_encoding_label = '字符编码：';
$html_add = '添加';
$html_contacts = '%1$s 联系人';
$html_modify = '修改';
$html_back = '返回';
$html_contact_add = '添加新的联系人';
$html_contact_mod = '修改联系人';
$html_contact_first = '名';
$html_contact_last = '姓';
$html_contact_nick = '昵称';
$html_contact_mail = '电子邮件';
$html_contact_list = '联系人列表中的 %1$s';
$html_contact_del = '从联系人列表中';
$html_contact_count = '%1$d 联系人';
$html_contact_err1 = '联系人的最大数量是"%1$d"';
$html_contact_err2 = '您不能添加新的联系人';
$html_contact_err3 = '您没有权限访问联系人列表';
$html_contact_none = '无法找到没有联系人。';
$html_del_msg = '删除选定的邮件吗？';
$html_down_mail = '下载';
$original_msg = '-- 原始消息 --';
$to_empty = ' \'To\' 域不能为空 !';
$html_images_warning = '为了您的安全远程图片不会显示。';
$html_images_display = '显示图片';
$html_smtp_error_no_conn = '无法打开 SMTP 连接';
$html_smtp_error_unexpected = '意外的 SMTP 响应：';
$lang_could_not_connect = '无法连接到服务器';
$lang_invalid_msg_num = '错误的邮件编号';
$html_file_upload_attack = '可能的文件上传攻击';
$html_invalid_email_address = '无效的电子邮件地址';
$html_invalid_msg_per_page = '每页显示的邮件数无效';
$html_invalid_wrap_msg = '无效的邮件自动换行宽度';
$html_seperate_msg_win = '在单独的窗口中的消息';
$html_err_file_contacts = '无法打开联系人文件以进行写入。';
$html_session_file_error = '无法打开会话文件以进行写入。';
$html_login_not_allowed = '此登录名不允许连接。';
$lang_err_send_delay = '您必须等待，两个电子邮件之间（%1$d 秒）';
$html_search = '搜索';
$html_new_session = '下一会话';
$html_fd_filename = '下载%1$s';
$html_fd_mailcount = '文件夹中{{PLURAL:$1|0=没有邮件|有%1$d封电子邮件}}。';
$html_fd_mailskip = '由于它们将超过php memory_limit，以下邮件将不会作为mbox文件的一部分：';
$html_fd_filesize = '大小%1$d';
$html_fd_skipcount = '有%1$d封电子邮件。';
$html_fd_largefolder = '根据您的下载速度，此次下载会因为脚本超时而失败。<br />请检查您下载的完整性或在 php.ini 中将 max_execution_time 设置为更高的值。';
$reset_clicked = '您真想清除此窗体么？';
$html_send_recover = '登录以还原丢失草稿！';
$html_send_discard = '点此放弃已保存草稿。';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/zh-hans.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: zh-hans.php 2650 2015-06-08 14:21:20Z siebrand $
 */
/** Simplified Chinese (中文（简体）‎)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Cathypilot0117
 * @author Hydra
 * @author Liu Hong <loyaliu@21cn.com>
 * @author Liuxinyu970226
 * @author PhiLiP
 * @author Wilsonmess
 * @author Yfdyh000
 */

$lang_locale = 'zh_CN.UTF-8';
$default_date_format = '%Y年%m月%d日';
$no_locale_date_format = '%Y年-%m月-%d日';
$default_time_format = '%I:%M %p';
$err_user_empty = '用户名为空';
$err_passwd_empty = '密码为空';
$alt_delete = '删除选择的邮件';
$alt_delete_one = '删除邮件';
$alt_new_msg = '新消息';
$alt_reply = '回复作者';
$alt_reply_all = '回复所有';
$alt_forward = '转发';
$alt_next = '下一个';
$alt_prev = '上一个';
$title_next_page = '下一页';
$title_prev_page = '上一页';
$title_next_msg = '下一个邮件';
$title_prev_msg = '上一个邮件';
$html_theme_label = '主题：';
$html_welcome = '欢迎来到%1$s';
$html_login = '登录';
$html_user_label = '用户：';
$html_passwd_label = '密码：';
$html_submit = '提交';
$html_help = '帮助';
$html_server_label = '服务器：';
$html_wrong = '用户名或密码不正确';
$html_retry = '重试';
$html_remember = '记住设置';
$html_lang_label = '语言：';
$html_msgperpage_label = '每页消息数：';
$html_preferences = '参数设置';
$html_full_name_label = '全名：';
$html_email_address_label = '电邮地址：';
$html_bccself = '密件抄送自我';
$html_hide_addresses = '隐藏地址';
$html_outlook_quoting = '使用Microsoft Outlook样式的引用';
$html_reply_to = '回复';
$html_reply_to_label = '回复：';
$html_use_signature = '用户签名';
$html_signature = '签名';
$html_signature_label = '签名：';
$html_reply_leadin_label = '中铅对的回复：';
$html_prefs_updated = '参数设置已更新';
$html_manage_folders_link = '管理 IMAP 文件夹';
$html_manage_filters_link = '管理电子邮件过滤器';
$html_use_graphical_smilies = '使用图形化的表情符号';
$html_sent_folder_label = '将已发送邮件复制至专用的文件夹：';
$html_trash_folder_label = '将欲删除邮件移动至专用的文件夹：';
$html_colored_quotes = '彩色引用';
$html_display_struct = '结构化的显示文本';
$html_send_html_mail = '以HTML格式发送电子邮件';
$html_folders = '文件夹';
$html_folders_create_failed = '无法创建文件夹！';
$html_folders_sub_failed = '无法订阅至文件夹！';
$html_folders_unsub_failed = '无法从文件夹退订！';
$html_folders_rename_failed = '文件夹无法重命名！';
$html_folders_updated = '文件夹已更新';
$html_folder_subscribe = '订阅';
$html_folder_rename = '重命名';
$html_folder_create = '创建新文件夹';
$html_folder_remove = '取消订阅';
$html_folder_delete = '删除';
$html_folder_to = '至';
$html_filter_remove = '删除';
$html_filter_body = '邮件正文';
$html_filter_subject = '邮件主题';
$html_filter_to = '字段';
$html_filter_cc = '抄送字段';
$html_filter_from = '从字段';
$html_filter_change_tip = '若要更改筛选器只是覆盖它。';
$html_reapply_filters = '重新应用的所有筛选器';
$html_filter_contains = '包含';
$html_filter_name = '筛选器名称';
$html_filter_action = '筛选操作';
$html_filter_moveto = '移动到';
$html_select_one = '--选择其一--';
$html_and = '和';
$html_new_msg_in = '新消息于';
$html_or = '或';
$html_move = '移动';
$html_copy = '拷贝';
$html_messages_to = '选定的邮件';
$html_gotopage = '转到页';
$html_gotofolder = '转到文件夹';
$html_other_folders = '文件夹列表';
$html_page = '页面';
$html_of = '/';
$html_view_header = '浏览邮件头';
$html_remove_header = '隐藏邮件头';
$html_inbox = '收件箱';
$html_new_msg = '写邮件';
$html_reply = '回复';
$html_reply_short = '回复：';
$html_reply_all = '回复所有';
$html_forward = '转发';
$html_forward_short = '转发：';
$html_forward_info = '转发的邮件将这一以附件的形式发送。';
$html_delete = '删除';
$html_new = '新';
$html_mark = '删除';
$html_att_label = '附件：';
$html_atts_label = '附件:';
$html_unknown = '[未知]';
$html_part_x = '部分 %s';
$html_attach = '附件';
$html_attach_forget = '在发送邮件之前，你必须选一个文件!';
$html_attach_delete = '删除选择';
$html_attach_none = '您必须选择要附加的文件！';
$html_sort_by = '排序方式';
$html_sort = '排序';
$html_from = '发件人';
$html_from_label = '从：';
$html_subject = '主题';
$html_subject_label = '主题：';
$html_date = '日期';
$html_date_label = '日期：';
$html_sent_label = '发送';
$html_wrote = '写道';
$html_quote_wrote = '在%1$s %2$s，%3$s写到：';
$html_size = '大小';
$html_totalsize = '总大小';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = '字节';
$html_filename = '文件名';
$html_to = '自';
$html_to_label = '至：';
$html_cc = '抄送';
$html_cc_label = '抄送：';
$html_bcc_label = '密送：';
$html_nosubject = '没有主题';
$html_send = '发送';
$html_cancel = '取消';
$html_no_mail = '没有邮件.';
$html_logout = '退出';
$html_msg = '邮件';
$html_msgs = '邮件';
$html_configuration = '此服务器未做好设置！';
$html_priority = '优先';
$html_priority_label = '优先级：';
$html_lowest = '最低';
$html_low = '低';
$html_normal = '正常';
$html_high = '高';
$html_highest = '最高';
$html_flagged = '标记';
$html_spam = '垃圾邮件';
$html_spam_warning = '此消息已被列为垃圾邮件。';
$html_receipt = '请求返回回执';
$html_select = '请选择';
$html_select_all = '反向选择';
$html_select_contacts = '选择联系人';
$html_loading_image = '加载图像';
$html_send_confirmed = '您的电子邮件被接受为传递';
$html_no_sendaction = '没有指定的操作。尝试启用 JavaScript。';
$html_error_occurred = '出现了一个错误';
$html_prefs_file_error = '无法打开首选项文件以进行写入。';
$html_wrap = '要自动换行，传出消息的字符数：';
$html_wrap_none = '不换行';
$html_usenet_separator = '新闻组分隔符（"-- \n"）在签名之前';
$html_mark_as = '将标记为';
$html_read = '阅读';
$html_unread = '未读';
$html_encoding_label = '字符编码：';
$html_add = '添加';
$html_contacts = '%1$s 联系人';
$html_modify = '修改';
$html_back = '返回';
$html_contact_add = '添加新的联系人';
$html_contact_mod = '修改联系人';
$html_contact_first = '名';
$html_contact_last = '姓';
$html_contact_nick = '昵称';
$html_contact_mail = '电子邮件';
$html_contact_list = '联系人列表中的 %1$s';
$html_contact_del = '从联系人列表中';
$html_contact_count = '%1$d 联系人';
$html_contact_err1 = '联系人的最大数量是"%1$d"';
$html_contact_err2 = '您不能添加新的联系人';
$html_contact_err3 = '您没有权限访问联系人列表';
$html_contact_none = '无法找到没有联系人。';
$html_contact_ruler_top = '返回页首';
$html_contact_listcheck_title = '检查以添加邮件至列表。';
$html_contact_list_add = '添加至列表';
$html_contact_listname = '列表名称';
$html_contact_listonly = '只列出';
$html_contact_all = '显示全部';
$html_contact_add_confirm = '将邮件附加至现有的列表么？';
$html_del_msg = '删除选定的邮件吗？';
$html_down_mail = '下载';
$original_msg = '-- 原始消息 --';
$to_empty = ' \'To\' 域不能为空 !';
$html_images_warning = '为了您的安全远程图片不会显示。';
$html_images_display = '显示图片';
$html_smtp_error_no_conn = '无法打开 SMTP 连接';
$html_smtp_error_unexpected = '意外的 SMTP 响应：';
$lang_could_not_connect = '无法连接到服务器';
$lang_invalid_msg_num = '错误的邮件编号';
$html_file_upload_attack = '可能的文件上传攻击';
$html_invalid_email_address = '无效的电子邮件地址';
$html_invalid_msg_per_page = '每页显示的邮件数无效';
$html_invalid_wrap_msg = '无效的邮件自动换行宽度';
$html_seperate_msg_win = '在单独的窗口中的消息';
$html_err_file_contacts = '无法打开联系人文件以进行写入。';
$html_session_file_error = '无法打开会话文件以进行写入。';
$html_login_not_allowed = '此登录名不允许连接。';
$lang_err_send_delay = '您必须等待，两个电子邮件之间（%1$d 秒）';
$html_search = '搜索';
$html_new_session = '下一会话';
$html_fd_filename = '下载%1$s';
$html_fd_mailcount = '文件夹中{{PLURAL:$1|0=没有邮件|有%1$d封电子邮件}}。';
$html_fd_mailskip = '由于它们将超过php memory_limit，以下邮件将不会作为mbox文件的一部分：';
$html_fd_filesize = '大小%1$d';
$html_fd_skipcount = '有%1$d封电子邮件。';
$html_fd_largefolder = '根据您的下载速度，此次下载会因为脚本超时而失败。<br />请检查您下载的完整性或在 php.ini 中将 max_execution_time 设置为更高的值。';
$reset_clicked = '您真想清除此窗体么？';
$html_send_recover = '登录以还原丢失草稿！';
$html_send_discard = '点此放弃已保存草稿。';
$html_collect_label = '自动收集电子邮件地址：';
$html_collect_option0 = '从不';
$html_collect_option1 = '只从发出的电子邮件';
$html_collect_option2 = '只从打开的电子邮件';
$html_collect_option3 = '总是';
